@@ -25,9 +25,10 @@
 simple graphics.
 
 the following command line flags can be used (typically under unix)
-	-notex		Do not use any textures
-	-noshadow[s]	Do not draw any shadows
-	-pause		Start the simulation paused
+  -notex              Do not use any textures
+  -noshadow[s]        Do not draw any shadows
+  -pause              Start the simulation paused
+  -texturepath <path> Inform an alternative textures path
 
 TODO
 ----
@@ -42,6 +43,7 @@ manage openGL state changes better
 
 #include <ode/ode.h>
 #include "config.h"
+
 #ifdef HAVE_APPLE_OPENGL_FRAMEWORK
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
@@ -57,7 +59,7 @@ manage openGL state changes better
 // misc
 
 #ifndef DEFAULT_PATH_TO_TEXTURES
-#ifdef WIN32
+#if 0
 #define DEFAULT_PATH_TO_TEXTURES "..\\textures\\"
 #else
 #define DEFAULT_PATH_TO_TEXTURES "../textures/"
@@ -107,6 +109,17 @@ static void normalizeVector3 (float v[3])
   }
 }
 
+static void crossProduct3(float res[3], const float a[3], const float b[3])
+{
+  float res_0 = a[1]*b[2] - a[2]*b[1];
+  float res_1 = a[2]*b[0] - a[0]*b[2];
+  float res_2 = a[0]*b[1] - a[1]*b[0];
+  // Only assign after all the calculations are over to avoid incurring memory aliasing
+  res[0] = res_0;
+  res[1] = res_1;
+  res[2] = res_2;
+}
+
 //***************************************************************************
 // PPM image object
 
@@ -614,7 +627,7 @@ static void drawTriangle (const float *v0, const float *v1, const float *v2, int
   v[0] = v2[0] - v0[0];
   v[1] = v2[1] - v0[1];
   v[2] = v2[2] - v0[2];
-  dCROSS (normal,=,u,v);
+  crossProduct3(normal,u,v);
   normalizeVector3 (normal);
 
   glBegin(solid ? GL_TRIANGLES : GL_LINE_STRIP);
@@ -634,7 +647,7 @@ static void drawTriangleD (const double *v0, const double *v1, const double *v2,
   v[0] = float( v2[0] - v0[0] );
   v[1] = float( v2[1] - v0[1] );
   v[2] = float( v2[2] - v0[2] );
-  dCROSS (normal,=,u,v);
+  crossProduct3(normal,u,v);
   normalizeVector3 (normal);
 
   glBegin(solid ? GL_TRIANGLES : GL_LINE_STRIP);
@@ -734,8 +747,6 @@ static void drawCapsule (float l, float r)
     start_nx = start_nx2;
     start_ny = start_ny2;
   }
-
-  glPopMatrix();
 }
 
 
@@ -883,7 +894,7 @@ static Texture *texture[4+1]; // +1 since index 0 is not used
 
 
 
-#ifndef macintosh
+#if !defined(macintosh) || defined(ODE_PLATFORM_OSX)
 
 void dsStartGraphics (int width, int height, dsFunctions *fn)
 {
@@ -1270,6 +1281,9 @@ extern "C" void dsSimulationLoop (int argc, char **argv,
     if (strcmp(argv[i],"-noshadow")==0) use_shadows = 0;
     if (strcmp(argv[i],"-noshadows")==0) use_shadows = 0;
     if (strcmp(argv[i],"-pause")==0) initial_pause = 1;
+    if (strcmp(argv[i],"-texturepath")==0)
+      if (++i < argc)
+        fn->path_to_textures = argv[i];
   }
 
   if (fn->version > DS_VERSION)
@@ -1481,10 +1495,8 @@ extern "C" void dsDrawCapsule (const float pos[3], const float R[12],
 }
 
 
-void dsDrawLine (const float pos1[3], const float pos2[3])
+static void drawLine(const float pos1[3], const float pos2[3])
 {
-  setupDrawingMode();
-  glColor3f (color[0],color[1],color[2]);
   glDisable (GL_LIGHTING);
   glLineWidth (2);
   glShadeModel (GL_FLAT);
@@ -1495,8 +1507,26 @@ void dsDrawLine (const float pos1[3], const float pos2[3])
 }
 
 
-void dsDrawBoxD (const double pos[3], const double R[12],
-		 const double sides[3])
+extern "C" void dsDrawLine (const float pos1[3], const float pos2[3])
+{
+  setupDrawingMode();
+  glColor4f(color[0], color[1], color[2], color[3]);
+  drawLine(pos1, pos2);
+
+  if (use_shadows) {
+    setShadowDrawingMode();
+    setShadowTransform();
+
+    drawLine(pos1, pos2);
+
+    glPopMatrix();
+    glDepthRange (0,1);
+  }
+}
+
+
+extern "C" void dsDrawBoxD (const double pos[3], const double R[12],
+                            const double sides[3])
 {
   int i;
   float pos2[3],R2[12],fsides[3];
