@@ -28,6 +28,8 @@
 #pragma warning(disable:4244 4305)  // for VC++, no precision loss complaints
 #endif
 
+#include "icosahedron_geom.h"
+
 
 //<---- Convex Object
 dReal planes[]= // planes for a cube, these should coincide with the face array
@@ -275,12 +277,21 @@ static void command (int cmd)
     else if (cmd == 'v') 
       {
 	dMassSetBox (&m,DENSITY,0.25,0.25,0.25);
+#if 0
 	obj[i].geom[0] = dCreateConvex (space,
 					planes,
 					planecount,
 					points,
 					pointcount,
 					polygons);
+#else
+	obj[i].geom[0] = dCreateConvex (space,
+					Sphere_planes,
+					Sphere_planecount,
+					Sphere_points,
+					Sphere_pointcount,
+					Sphere_polygons);
+#endif
       }
     //----> Convex Object
     else if (cmd == 'y') {
@@ -478,12 +489,20 @@ void drawGeom (dGeomID g, const dReal *pos, const dReal *R, int show_aabb)
   //<---- Convex Object
   else if (type == dConvexClass) 
     {
-      //dVector3 sides={0.50,0.50,0.50};
+#if 0
       dsDrawConvex(pos,R,planes,
 		   planecount,
 		   points,
 		   pointcount,
 		   polygons);
+#else
+      dsDrawConvex(pos,R,
+       Sphere_planes,
+		   Sphere_planecount,
+		   Sphere_points,
+		   Sphere_pointcount,
+		   Sphere_polygons);
+#endif
     }
   //----> Convex Object
   else if (type == dCylinderClass) {
@@ -497,11 +516,11 @@ void drawGeom (dGeomID g, const dReal *pos, const dReal *R, int show_aabb)
     const dReal *R2 = dGeomGetRotation (g2);
     dVector3 actual_pos;
     dMatrix3 actual_R;
-    dMULTIPLY0_331 (actual_pos,R,pos2);
+    dMultiply0_331 (actual_pos,R,pos2);
     actual_pos[0] += pos[0];
     actual_pos[1] += pos[1];
     actual_pos[2] += pos[2];
-    dMULTIPLY0_333 (actual_R,R,R2);
+    dMultiply0_333 (actual_R,R,R2);
     drawGeom (g2,actual_pos,actual_R,0);
   }
   if (show_body) {
@@ -604,10 +623,6 @@ int main (int argc, char **argv)
   fn.command = &command;
   fn.stop = 0;
   fn.path_to_textures = DRAWSTUFF_TEXTURE_PATH;
-  if(argc==2)
-    {
-        fn.path_to_textures = argv[1];
-    }
 
   // create world
   dInitODE2(0);
@@ -633,9 +648,20 @@ int main (int argc, char **argv)
   dCreatePlane (space,0,0,1,0);
   memset (obj,0,sizeof(obj));
 
+  dThreadingImplementationID threading = dThreadingAllocateMultiThreadedImplementation();
+  dThreadingThreadPoolID pool = dThreadingAllocateThreadPool(4, 0, dAllocateFlagBasicData, NULL);
+  dThreadingThreadPoolServeMultiThreadedImplementation(pool, threading);
+  // dWorldSetStepIslandsProcessingMaxThreadCount(world, 1);
+  dWorldSetStepThreadingImplementation(world, dThreadingImplementationGetFunctions(threading), threading);
+
   // run simulation
   dsSimulationLoop (argc,argv,352,288,&fn);
 
+  dThreadingImplementationShutdownProcessing(threading);
+  dThreadingFreeThreadPool(pool);
+  dWorldSetStepThreadingImplementation(world, NULL, NULL);
+  dThreadingFreeImplementation(threading);
+
   dJointGroupDestroy (contactgroup);
   dSpaceDestroy (space);
   dWorldDestroy (world);
