@@ -155,9 +155,6 @@ dGeomID TriMesh2;
 
 dReal heightfield_callback( void* pUserData, int x, int z )
 {
-	dIASSERT( x < HFIELD_WSTEP );
-	dIASSERT( z < HFIELD_DSTEP );
-
 	dReal fx = ( ((dReal)x) - ( HFIELD_WSTEP-1 )/2 ) / (dReal)( HFIELD_WSTEP-1 );
 	dReal fz = ( ((dReal)z) - ( HFIELD_DSTEP-1 )/2 ) / (dReal)( HFIELD_DSTEP-1 );
 
@@ -493,11 +490,11 @@ void drawGeom (dGeomID g, const dReal *pos, const dReal *R, int show_aabb)
     const dReal *R2 = dGeomGetRotation (g2);
     dVector3 actual_pos;
     dMatrix3 actual_R;
-    dMULTIPLY0_331 (actual_pos,R,pos2);
+    dMultiply0_331 (actual_pos,R,pos2);
     actual_pos[0] += pos[0];
     actual_pos[1] += pos[1];
     actual_pos[2] += pos[2];
-    dMULTIPLY0_333 (actual_R,R,R2);
+    dMultiply0_333 (actual_R,R,R2);
     drawGeom (g2,actual_pos,actual_R,0);
   }
 
@@ -528,8 +525,7 @@ static void simLoop (int pause)
   dSpaceCollide (space,0,&nearCallback);
   
   //if (!pause) dWorldStep (world,0.05);
-  //if (!pause) dWorldQuickStep (world,0.05);
-  if (!pause) dWorldStepFast1 (world,0.05, 5);
+  if (!pause) dWorldQuickStep (world,0.05);
 
 
   if (write_world) {
@@ -694,10 +690,6 @@ int main (int argc, char **argv)
 	fn.command = &command;
 	fn.stop = 0;
 	fn.path_to_textures = DRAWSTUFF_TEXTURE_PATH;
-	if(argc==2)
-	{
-		fn.path_to_textures = argv[1];
-	}
 
 	// create world
 	dInitODE2(0);
@@ -750,9 +742,20 @@ int main (int argc, char **argv)
 	dGeomSetRotation( gheight, R );
 	dGeomSetPosition( gheight, pos[0], pos[1], pos[2] );
 
+  dThreadingImplementationID threading = dThreadingAllocateMultiThreadedImplementation();
+  dThreadingThreadPoolID pool = dThreadingAllocateThreadPool(4, 0, dAllocateFlagBasicData, NULL);
+  dThreadingThreadPoolServeMultiThreadedImplementation(pool, threading);
+  // dWorldSetStepIslandsProcessingMaxThreadCount(world, 1);
+  dWorldSetStepThreadingImplementation(world, dThreadingImplementationGetFunctions(threading), threading);
+
 	// run simulation
 	dsSimulationLoop (argc,argv,352,288,&fn);
 
+  dThreadingImplementationShutdownProcessing(threading);
+  dThreadingFreeThreadPool(pool);
+  dWorldSetStepThreadingImplementation(world, NULL, NULL);
+  dThreadingFreeImplementation(threading);
+
 	dJointGroupDestroy (contactgroup);
 	dSpaceDestroy (space);
 	dWorldDestroy (world);
