@@ -53,8 +53,6 @@
 #define dsDrawCapsule dsDrawCapsuleD
 #endif
 
-//using namespace ode;
-
 enum IDX_CYL_DIM
 {
   RADIUS,
@@ -109,7 +107,8 @@ const int catBits[LAST_INDEX_CNT] =
     0x0008, ///< INT slider category
     0x0010, ///< AXIS1 universal category
     0x0020, ///< AXIS2 universal category
-    0x0040, ///< Ground category
+    0x0040, ///< ANCHOR category
+    0x0080, ///< Ground category
     ~0L,    ///< All categories
     0x0004 | 0x0008 | 0x0010 | 0x0020 ///< JOINT category
   };
@@ -124,10 +123,10 @@ static float hpr[3] = {-180.000f,-25.5000f,0.0000f};
 
 
 //world,space,body & geom
-static dWorld           world;
+static dWorldID         world;
 static dSpaceID         space;
 static dJointGroupID    contactgroup;
-static dBody            body[NUM_PARTS];
+static dBodyID          body[NUM_PARTS];
 static dGeomID          geom[NUM_PARTS];
 
 static dJoint *joint;
@@ -146,7 +145,7 @@ static void nearCallback (void *data, dGeomID o1, dGeomID o2)
 
   dBodyID b1 = dGeomGetBody (o1);
   dBodyID b2 = dGeomGetBody (o2);
-  if (b1 && b2 && dAreConnectedExcluding (b1,b2,dJointTypeContact) ) return;
+  //if (b1 && b2 && dAreConnectedExcluding (b1,b2,dJointTypeContact) ) return;
   const int N = 10;
   dContact contact[N];
   n = dCollide (o1,o2,N,&contact[0].geom,sizeof (dContact) );
@@ -241,52 +240,53 @@ case 'h' : case 'H' : case '?' :
 
       // Force
   case 'q' : case 'Q' :
-      body[D].addForce(40,0,0);
+      dBodyAddForce(body[D],40,0,0);
       break;
   case 'w' : case 'W' :
-      body[D].addForce(-40,0,0);
+      dBodyAddForce(body[D],-40,0,0);
       break;
 
   case 'a' : case 'A' :
-      body[D].addForce(0,40,0);
+      dBodyAddForce(body[D],0,40,0);
       break;
   case 's' : case 'S' :
-      body[D].addForce(0,-40,0);
+      dBodyAddForce(body[D],0,-40,0);
       break;
 
   case 'z' : case 'Z' :
-      body[D].addForce(0,0,40);
+      dBodyAddForce(body[D],0,0,40);
       break;
   case 'x' : case 'X' :
-      body[D].addForce(0,0,-40);
+      dBodyAddForce(body[D],0,0,-40);
       break;
 
       // Torque
   case 'e': case 'E':
-      body[D].addTorque(0.1,0,0);
+      dBodyAddTorque(body[D],0.1,0,0);
       break;
   case 'r': case 'R':
-      body[D].addTorque(-0.1,0,0);
+      dBodyAddTorque(body[D],-0.1,0,0);
       break;
 
   case 'd': case 'D':
-      body[D].addTorque(0, 0.1,0);
+      dBodyAddTorque(body[D],0, 0.1,0);
       break;
   case 'f': case 'F':
-      body[D].addTorque(0,-0.1,0);
+      dBodyAddTorque(body[D],0,-0.1,0);
       break;
 
   case 'c': case 'C':
-      body[D].addTorque(0,0,0.1);
+      dBodyAddTorque(body[D],0,0,0.1);
       break;
   case 'v': case 'V':
-      body[D].addTorque(0,0,0.1);
+      dBodyAddTorque(body[D],0,0,0.1);
       break;
 
       // Velocity of joint
   case ',': case '<' : {
       dReal vel = joint->getParam (dParamVel3) - VEL_INC;
       joint->setParam (dParamVel3, vel);
+	  joint->setParam (dParamFMax3, 2);
       std::cout<<"Velocity = "<<vel<<"  FMax = 2"<<'\n';
     }
     break;
@@ -294,6 +294,7 @@ case 'h' : case 'H' : case '?' :
   case '.': case '>' : {
       dReal vel = joint->getParam (dParamVel3) + VEL_INC;
       joint->setParam (dParamVel3, vel);
+	  joint->setParam (dParamFMax3, 2);
       std::cout<<"Velocity = "<<vel<<"  FMax = 2"<<'\n';
     }
     break;
@@ -342,11 +343,11 @@ case 'h' : case 'H' : case '?' :
 
   case 'g': case 'G' : {
       dVector3 g;
-      world.getGravity(g);
+      dWorldGetGravity(world, g);
       if (  g[2]< -0.1 )
-        world.setGravity(0, 0, 0);
+        dWorldSetGravity(world, 0, 0, 0);
       else
-        world.setGravity(0, 0, -0.5);
+        dWorldSetGravity(world, 0, 0, -0.5);
 
     }
 
@@ -589,7 +590,8 @@ int main (int argc, char **argv)
 
   dInitODE2(0);
 
-  world.setERP (0.8);
+  world = dWorldCreate();
+  dWorldSetERP (world, 0.8);
 
   space = dSimpleSpaceCreate (0);
   contactgroup = dJointGroupCreate (0);
@@ -600,7 +602,7 @@ int main (int argc, char **argv)
   dMass m;
 
   // Create the body attached to the World
-  body[W].create (world);
+  body[W] = dBodyCreate (world);
   // Main axis of cylinder is along X=1
   m.setBox (1, boxDim[X], boxDim[Y], boxDim[Z]);
   m.adjust (Mass1);
@@ -608,14 +610,14 @@ int main (int argc, char **argv)
   dGeomSetBody (geom[W], body[W]);
   dGeomSetCategoryBits (geom[W], catBits[W]);
   dGeomSetCollideBits (geom[W], catBits[ALL] & (~catBits[W]) & (~catBits[JOINT]) );
-  body[W].setMass(m);
+  dBodySetMass (body[W], &m);
 
 
 
 
 
   // Create the dandling body
-  body[D].create(world);
+  body[D] = dBodyCreate (world);
   // Main axis of capsule is along X=1
   m.setBox (1, boxDim[X], boxDim[Y], boxDim[Z]);
   m.adjust (Mass1);
@@ -623,17 +625,17 @@ int main (int argc, char **argv)
   dGeomSetBody (geom[D], body[D]);
   dGeomSetCategoryBits (geom[D], catBits[D]);
   dGeomSetCollideBits (geom[D], catBits[ALL] & (~catBits[D]) & (~catBits[JOINT]) );
-  body[D].setMass(&m);
+  dBodySetMass (body[D], &m);
 
 
   // Create the external part of the slider joint
-  geom[EXT] = dCreateBox (space, extDim[X], extDim[Y], extDim[Z]);
+  geom[EXT] = dCreateBox (0, extDim[X], extDim[Y], extDim[Z]);
   dGeomSetCategoryBits (geom[EXT], catBits[EXT]);
   dGeomSetCollideBits (geom[EXT],
                        catBits[ALL] & (~catBits[JOINT]) & (~catBits[W]) & (~catBits[D]) );
 
   // Create the internal part of the slider joint
-  geom[INT] = dCreateBox (space, INT_EXT_RATIO*extDim[X],
+  geom[INT] = dCreateBox (0, INT_EXT_RATIO*extDim[X],
                           INT_EXT_RATIO*extDim[Y],
                           INT_EXT_RATIO*extDim[Z]);
   dGeomSetCategoryBits (geom[INT], catBits[INT]);
@@ -642,33 +644,30 @@ int main (int argc, char **argv)
 
 
   dMatrix3 R;
-  dGeomID id;
   // Create the first axis of the universal joi9nt
-  geom[AXIS1] = dCreateGeomTransform (space);
+  geom[AXIS1] = dCreateGeomTransform (0);
   //Rotation of 90deg around y
   dRFromAxisAndAngle (R, 0,1,0, 0.5*PI);
   dGeomSetRotation (geom[AXIS1], R);
   dGeomSetCategoryBits (geom[AXIS1], catBits[AXIS1]);
   dGeomSetCollideBits (geom[AXIS1],
                        catBits[ALL]  & ~catBits[JOINT] & ~catBits[W] & ~catBits[D]);
-  id = geom[AXIS1];
   dGeomTransformSetGeom (geom[AXIS1],  dCreateCylinder (0, axDim[RADIUS], axDim[LENGTH]) );
 
 
   // Create the second axis of the universal joint
-  geom[AXIS2] = dCreateGeomTransform (space);
+  geom[AXIS2] = dCreateGeomTransform (0);
   //Rotation of 90deg around y
   dRFromAxisAndAngle (R, 1,0,0, 0.5*PI);
   dGeomSetRotation (geom[AXIS2], R);
   dGeomSetCategoryBits (geom[AXIS2], catBits[AXIS2]);
   dGeomSetCollideBits (geom[AXIS2],
                        catBits[ALL]  & ~catBits[JOINT] & ~catBits[W] & ~catBits[D]);
-  id = geom[AXIS2];
   dGeomTransformSetGeom (geom[AXIS2],  dCreateCylinder (0, axDim[RADIUS], axDim[LENGTH]) );
 
 
   // Create the anchor
-  geom[ANCHOR] = dCreateBox (space, ancDim[X], ancDim[Y], ancDim[Z]);
+  geom[ANCHOR] = dCreateBox (0, ancDim[X], ancDim[Y], ancDim[Z]);
   dGeomSetCategoryBits (geom[ANCHOR], catBits[ANCHOR]);
   dGeomSetCollideBits (geom[ANCHOR],
                        catBits[ALL] & (~catBits[JOINT]) & (~catBits[W]) & (~catBits[D]) );
@@ -676,7 +675,7 @@ int main (int argc, char **argv)
 
 
   if (body[W]) {
-    body[W].setPosition(0, 0, 5);
+    dBodySetPosition(body[W], 0, 0, 5);
   }
 
 
@@ -698,7 +697,7 @@ int main (int argc, char **argv)
   }
 
   if (body[D]) {
-    body[D].setPosition(0,0,1.5);
+    dBodySetPosition (body[D], 0,0,1.5);
   }
 
 
