@@ -348,11 +348,11 @@ void drawGeom (dGeomID g, const dReal *pos, const dReal *R, int show_aabb)
     const dReal *R2 = dGeomGetRotation (g2);
     dVector3 actual_pos;
     dMatrix3 actual_R;
-    dMULTIPLY0_331 (actual_pos,R,pos2);
+    dMultiply0_331 (actual_pos,R,pos2);
     actual_pos[0] += pos[0];
     actual_pos[1] += pos[1];
     actual_pos[2] += pos[2];
-    dMULTIPLY0_333 (actual_R,R,R2);
+    dMultiply0_333 (actual_R,R,R2);
     drawGeom (g2,actual_pos,actual_R,0);
   }
 
@@ -399,7 +399,7 @@ static void simLoop (int pause)
   dSpaceCollide (space,0,&nearCallback);
 
 
-#if 0
+#if 1
   // What is this for??? - Bram
   if (!pause) 
   {
@@ -415,7 +415,7 @@ static void simLoop (int pause)
 #endif
 
   //if (!pause) dWorldStep (world,0.05);
-  if (!pause) dWorldStepFast1 (world,0.05, 5);
+  if (!pause) dWorldQuickStep (world,0.05);
 
   for (int j = 0; j < dSpaceGetNumGeoms(space); j++){
 	  dSpaceGetGeom(space, j);
@@ -535,10 +535,6 @@ int main (int argc, char **argv)
   fn.command = &command;
   fn.stop = 0;
   fn.path_to_textures = DRAWSTUFF_TEXTURE_PATH;
-  if(argc==2)
-    {
-        fn.path_to_textures = argv[1];
-    }
 
   // create world
   dInitODE2(0);
@@ -572,9 +568,20 @@ int main (int argc, char **argv)
   dRFromAxisAndAngle(Rotation, 1, 0, 0, M_PI / 2);
   dGeomSetRotation(TriMesh2, Rotation);}
   
+  dThreadingImplementationID threading = dThreadingAllocateMultiThreadedImplementation();
+  dThreadingThreadPoolID pool = dThreadingAllocateThreadPool(4, 0, dAllocateFlagBasicData, NULL);
+  dThreadingThreadPoolServeMultiThreadedImplementation(pool, threading);
+  // dWorldSetStepIslandsProcessingMaxThreadCount(world, 1);
+  dWorldSetStepThreadingImplementation(world, dThreadingImplementationGetFunctions(threading), threading);
+
   // run simulation
   dsSimulationLoop (argc,argv,352,288,&fn);
 
+  dThreadingImplementationShutdownProcessing(threading);
+  dThreadingFreeThreadPool(pool);
+  dWorldSetStepThreadingImplementation(world, NULL, NULL);
+  dThreadingFreeImplementation(threading);
+
   dJointGroupDestroy (contactgroup);
   dSpaceDestroy (space);
   dWorldDestroy (world);
